km3pipe.hardware.PMT
====================

.. currentmodule:: km3pipe.hardware

.. autoclass:: PMT

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PMT.__init__
   
   

   
   
   